# jjjxutils

Some useful utility functions for Python.

## Installation

```bash
pip install jjjxutils
```

## Usage

There is no one single way to use this package. It is a collection of utility functions that I have found useful in my projects. You can use them as you see fit.

I should definitely write some documentation for this package. But for now, you will just have to explore the in-code documentation through comments and type hints.

## License

This package is licensed under the MIT License. See the [LICENSE](LICENSE) file for more information.
